91 Jewellery Stores in Mykonos - Page 1 of 7 | Mykonos, Cyclades, Greece
Author: ilove group ltd
Description: Jewellery for every budget, from rare diamonds to handmade beaded bracelets are available for you to choose from.
Keywords: Mykonos,Island,Greece,Resorts,Hotels,Villas,Bookings,Reviews,Holidays

- Fashion Stores ×
- Jewellery Stores ×
- Beauty Stores ×
- Home Deco Stores ×
- Souvenir Stores ×
- Supermarkets ×
- Kiosks ×
- Liquor Stores ×
- Local & Organic Stores ×
- Butchers ×
- News & Book Stores ×
- Music & DVD Stores ×
- IT & Computer Stores ×
- Electrical Stores ×
- Hardware Stores ×

#### There are 91 Jewellery Stores in Mykonos

D.S Gold DS Gold

At D.S. Gold you can experience all the pleasures of fine jewelry. Enjoy the confidence of wearing high quality jewelry without the exorbitant prices. For over a decade we have been and still are a family based business. Our jewelry is desi…

Ilias Lalaounis

ilias LALAoUNIS creations are designed and produced at the Lalaounis workshop in Athens where a 4,000 year old tradition of Greek art is kept alive. Age old techniques such as granulation, filigree and hand hammering are used along side modern techniques, to create jewelry inspired by ancient civilizations. Ilias LALAoUNIS jewel…

En Mykono

En Mykono Jewelry is a creation of Marily Soubasi, fashion designer. Marily studied design and handmade jewelry craft work in Athens and she has participated in numerous seminars of pottery and mosaic. Since 1996 she is living and working in Mykonos island where she designs and creates jewelry. In her studio-gallery in the Chora…

Gofas

At the end of the sixties the first GOFAS jewelry has been established in Athens. Since then, the GOFAS jewellery shops, located in Athens and in Mykonos Island, maintain a loyal and satisfied clientele. The jewelry we propose to our clients are unique, have a high quality and fulfill the highest production standards. The shops,…

Gold Star

In the early 30's Spiros and George Nikolopoulos established their first jewellery shop in Patras,Greece. Later on in the mid 70's Vasilis Nikolopoulos visited Mykonos island and never left. He and his wife Joanna, fell in love with it's aura and glamour, and decided to open up 'Marquise' and 'Gold …

Tourbillon

Only in a Tourbillon Boutique do you come across seven watch brands as attractive and exclusive as Breguet, Blancpain, Glashette Original, Jaquet Droz, Laon Hatot, Omega and Swatch. Their collections feature scores of models fitted with a tourbillon regulator, invented and patented in 1801, by watchmaking genius A.-L. Breguet. W…

Noufaro

The Noufaro workshop opened doors in 1990 and, since then, there is a new item produced every day. If you visit our shop in Mykonos you'll find more than 1000 different jewels and the number is constantly growing, as we create new designs together with our customers. In Noufaro, we aim for excellence in t…

- luxury
- popularity

Marquise

In the early 30's Spiros and George Nikolopoulos established their first jewellery shop in Patras,Greece. Later on in the mid 70's Vasilis Nikolopoulos visited Mykonos island and never left. He and his wife Joanna, fell in love with it's aura and glamour, and decided to open up 'Marquise' and 'Gold …

Kombologadiko

We began in 1999, when our love for the komboloy, led us to create the Kombologadiko shop, combining the past with the present. Quickly we expanded our business in many Greek cities, since we always wished to be as close to you as possible. Today you will find our shops in Athens, Nafplion old town, Arachova, Salonica and Mykono…

Franck Muller Boutique Franck Muller

The mechanical watchmaking complications invented by FRANCK MULLER are designed and developed at the heart of our own workshops. From the simple sketch of a world première mechanism to the execution of the plans, via the construction of a …

Fetish

All jewelry and objects are made using precious and semi-precious stones, precious metals and various other rare materials. All these, combined with the creator's imagination produce a truly wonderful result.

Delos Dolphins

Delos Dolphins started in 1986. We have since grown and carry a wide selection of Greek jewellery for visitors wanting to buy a momento that will remind them of their holidays in Greece. Additionally, our customers occasionally ask us to make jewellery for them using a specific metal or design and we always try to satisfy the ne…

Very Gavello

Rinaldo Gavello presents VERY GAVELLO, a new brand characterised by his unique style, following his unmistakeable attention to design and details. VERY GAVELLO jewels are in pink gold 9 kt, with essenza, and in silver 925/000.

Galerie Tsangarakis Tsangarakis

Since 1990, Galerie Tsangarakis has been in the business of fine jewelry, collectable art, and watches, both in Greece and abroad.

Karkalis

Over the last 60 years Karkalis company is highly distinguished all over the Greek and International market for the high quality and unique collections of hand made jewelry in pink gold, gold and platinum.